import { Padding } from '@bothrs/react-native-layout';
import { useState, useEffect, useRef } from 'react';
import { Animated, Pressable } from 'react-native';
import { useInterval } from 'usehooks-ts';
import { useReactNativeToast } from '../hooks/useReactNativeToast';
const ReactNativeToast = _ref => {
  let {
    id,
    theme,
    content,
    direction,
    timeout = 3000
  } = _ref;
  const [remove, setRemove] = useState(false);
  const appearAnimation = useRef(new Animated.Value(0)).current;
  const [remainingTime, setRemainingTime] = useState(timeout);
  const [intervalActive, setIntervalActive] = useState(true);
  const {
    removeToast
  } = useReactNativeToast();
  useInterval(() => {
    setRemainingTime(value => value - 16);
  }, intervalActive ? 16 : null);
  useEffect(() => {
    if (remainingTime < 0 || remove) {
      setIntervalActive(false);
      if (removeToast) {
        Animated.timing(appearAnimation, {
          toValue: 0,
          duration: 200,
          useNativeDriver: true
        }).start(_ref2 => {
          let {
            finished
          } = _ref2;
          if (finished) {
            removeToast(id);
          }
        });
      }
    }
  }, [remainingTime, remove]);
  useEffect(() => {
    Animated.timing(appearAnimation, {
      toValue: 1,
      duration: 200,
      useNativeDriver: true
    }).start();
  }, [appearAnimation]);
  function handlePress() {
    setRemove(true);
  }
  return /*#__PURE__*/React.createElement(Animated.View, {
    style: {
      opacity: appearAnimation,
      transform: [{
        translateY: appearAnimation.interpolate({
          inputRange: [0, 1],
          outputRange: [direction === 'bottom' ? 40 : -40, 0]
        })
      }, {
        scale: appearAnimation.interpolate({
          inputRange: [0, 1],
          outputRange: [0.7, 1]
        })
      }]
    }
  }, /*#__PURE__*/React.createElement(Pressable, {
    accessibilityRole: "button",
    onPress: handlePress,
    style: theme
  }, /*#__PURE__*/React.createElement(Padding, {
    amount: {
      horizontal: 12,
      vertical: 6
    }
  }, content)));
};
export { ReactNativeToast };
//# sourceMappingURL=ReactNativeToast.js.map